@@ -8,6 +8,9 @@ if(file.exists("./clinDR/inst/tests")) setwd("./clinDR/inst/tests")
 RNGkind("default")
 test_file('test.emaxsim.R')
 
+RNGkind("default")
+test_file('test.emaxsimBlocalParm.R')
+
 RNGkind("default")
 test_file('test.emaxsimB.R')
 
@@ -30,11 +33,17 @@ RNGkind("default")
 test_file('test.fitEmax.R')
 
 RNGkind("default")
-test_file('test.fitEmaxB.R')
+test_file('test.fitEmaxBlocalParm.R')
 
-RNGkind("default")
-test_file('test.genfunctions.R')
-
-RNGkind("default")
-test_file('test.checkMonoEmax.R')
+# RNGkind("default")
+# test_file('test.fitEmaxB.R')
+# 
+# RNGkind("default")
+# test_file('test.genfunctions.R')
+# 
+# RNGkind("default")
+# test_file('test.checkMonoEmaxlocalParm.R')
+# 
+# RNGkind("default")
+# test_file('test.checkMonoEmax.R')
 
