@@ -295,7 +295,7 @@ test_that("pboadj4 check absolute levels",{
 ### 4 parm model and grouped data, one protocol
 ### and replicated measurement per dose/protocol condition
 set.seed(12357)
-nsim<-1000
+nsim<-500
 doselev<-c(0,5,25,50,100,350)
 n<-20*c(78,81,81,81,77,80)
 n1<-sum(n)
@@ -529,7 +529,7 @@ dose<-rep(doselev,n)
 meanlev<-emaxfun(doselev,pop.parm)  
 meanrep<-emaxfun(dose,pop.parm)  
 clev<-0.9
-nsim<-1000
+nsim<-500
 covci<-matrix(logical(nsim*nd),ncol=nd)
 covpi<-matrix(logical(nsim*nd),ncol=nd)
 covdifci<-matrix(logical(nsim*nd),ncol=nd)
@@ -602,7 +602,7 @@ meanlev<-plogis(emaxfun(doselev,pop.parm))
 y01<-c(rep(1,length(meanlev)),rep(0,length(meanlev)))
 d01<-c(doselev,doselev)
 clev<-0.9
-nsim<-1000
+nsim<-500
 covci<-matrix(logical(nsim*nd),ncol=nd)
 covpi<-matrix(logical(nsim*nd),ncol=nd)
 covdifci<-matrix(logical(nsim*nd),ncol=nd)
@@ -643,24 +643,44 @@ for (i in 1:nsim){
 test_that("plot.fitEmax CI for binary data agree within 3se",{
 	expect_that(clev,
 							equals(as.numeric(max(apply(covci,2,mean,na.rm=TRUE))),
-										 tolerance=3*sqrt(.1*.9/nsim),scale=1))
+										 tolerance=0.04,scale=1))
+})
+test_that("plot.fitEmax CI for binary data agree within 3se",{
+	expect_that(clev,
+							equals(as.numeric(min(apply(covci,2,mean,na.rm=TRUE))),
+										 tolerance=0.04,scale=1))
 })
 test_that("plot.fitEmax PI for binary data agree within 3se",{
 	expect_that(clev,
 							equals(as.numeric(max(apply(covpi,2,mean,na.rm=TRUE))),
-										 tolerance=3*sqrt(.1*.9/nsim),scale=1))
+										 tolerance=0.04,scale=1))
+})
+test_that("plot.fitEmax PI for binary data agree within 3se",{
+	expect_that(clev,
+							equals(as.numeric(min(apply(covpi,2,mean,na.rm=TRUE))),
+										 tolerance=0.04,scale=1))
 })
 
 
 test_that("plot.fitEmax CI DIF for binary data agree within 3se",{
 	expect_that(clev,
 							equals(as.numeric(max(apply(covdifci[,-1],2,mean,na.rm=TRUE))),
-										 tolerance=3*sqrt(.1*.9/nsim),scale=1))
+										 tolerance=0.04,scale=1))
+})
+test_that("plot.fitEmax CI DIF for binary data agree within 3se",{
+	expect_that(clev,
+							equals(as.numeric(min(apply(covdifci[,-1],2,mean,na.rm=TRUE))),
+										 tolerance=0.04,scale=1))
 })
 test_that("plot.fitEmax PI DIF for binary data agree within 3se",{
 	expect_that(clev,
 							equals(as.numeric(max(apply(covdifpi[,-1],2,mean,na.rm=TRUE))),
-										 tolerance=3*sqrt(.1*.9/nsim),scale=1))
+										 tolerance=0.04,scale=1))
+})
+test_that("plot.fitEmax PI DIF for binary data agree within 3se",{
+	expect_that(clev,
+							equals(as.numeric(min(apply(covdifpi[,-1],2,mean,na.rm=TRUE))),
+										 tolerance=0.04,scale=1))
 })
 
 #################################################################################
